@@ -400,7 +400,7 @@ static const char *cmd_SSLCacheServerPort(
         g_szCacheServerPort = arg;
     else
         g_szCacheServerPort = ap_server_root_relative(cmd->pool, arg);
-    InitGlobalCache(g_szCacheServerPort);
+    ssl_gcache_Init(g_szCacheServerPort);
     return NULL;
 }
 
@@ -621,7 +621,7 @@ static void init_Module(server_rec *s, pool *p)
     /*
      *  launch SSL session cache process
      */
-    LaunchCache(pMainServer, p);
+    ssl_LaunchCache(pMainServer, p);
 
     /*
      *  Reconnect stderr to error log
@@ -753,13 +753,14 @@ static void init_GetCertAndKey(server_rec *s, pool *p, SSLConfigRec *pConfig)
      * Read server private key 
      * REMEMBER: Here SSLeay perhaps opens an interactive console dialog!!
      */
-    if (pConfig->szKeyFile)
+    if (pConfig->szKeyFile) {
         if (*pConfig->szKeyFile == '/')
             ap_cpystrn(szPath, pConfig->szKeyFile, sizeof(szPath));
         else
             ap_snprintf(szPath, sizeof(szPath), "%s/private/%s", 
                         __SSLeay X509_get_default_cert_area(), 
                         pConfig->szKeyFile);
+    }
     /* Otherwise the path already contains the name of the certificate file */
     init_GetPrivateKey(s, p, pConfig, szPath);
 
@@ -1179,7 +1180,6 @@ static int ssl_callback_SSLVerify(int ok, X509_STORE_CTX *ctx)
         s = __SSLeay X509_NAME_oneline(__SSLeay X509_get_issuer_name(xs), NULL, 0);
         if (s == NULL) {
             ssl_log_own(pConfig, "Verify error");
-            __SSLeay ERR_print_errors_fp(pConfig->fileLogFile);
             ssl_log_ssleay2apache(g_pCurrentConnection->server);
             return(0);
         }
@@ -1204,7 +1204,7 @@ static int ssl_callback_SSLVerify(int ok, X509_STORE_CTX *ctx)
 
 static int ssl_callback_NewSessionCache(SSL *pSSL, SSL_SESSION *pNew)
 {
-    SendSessionToServer(pNew);
+    ssl_SendSessionToServer(pNew);
     return 0;
 }
 
@@ -1214,7 +1214,7 @@ static SSL_SESSION *ssl_callback_GetSessionCache(
     SSL_SESSION *pSession;
 
     *pCopy = 0;
-    pSession = GetSessionFromServer(aucSessionID, nLength);
+    pSession = ssl_GetSessionFromServer(aucSessionID, nLength);
 
     return pSession;
 }
@@ -1284,13 +1284,11 @@ static BOOL ssl_int_SetCertStuff(conn_rec *conn)
     if (cert_file != NULL) {
         if (__SSLeay SSL_use_certificate(con, pConfig->px509Certificate) <= 0) {
             ssl_log_own(pConfig, "Unable to set certificate");
-            __SSLeay ERR_print_errors_fp(pConfig->fileLogFile);
             ssl_log_ssleay2apache(conn->server);
             return FALSE;
         }
         if (__SSLeay SSL_use_RSAPrivateKey(con, pConfig->prsaKey) <= 0) {
             ssl_log_own(pConfig, "Unable to set private key");
-            __SSLeay ERR_print_errors_fp(pConfig->fileLogFile);
             ssl_log_ssleay2apache(conn->server);
             return FALSE;
         }
@@ -1306,17 +1304,24 @@ static BOOL ssl_int_SetCertStuff(conn_rec *conn)
 
 #define MAX_SESSION_DER 100000
 
-static void LaunchCache(server_rec *s, pool *pPool)
+static void ssl_LaunchCache(server_rec *s, pool *pPool)
 {
     int pid;
 
     g_pServer = s;
-    pid = ap_spawn_child(pPool, CacheLauncher, g_szCacheServerPath, 
+    pid = ap_spawn_child(pPool, ssl_CacheLauncher, g_szCacheServerPath, 
                          kill_always, NULL, NULL, NULL);
+    if (pid == 0) {
+        ap_log_error(APLOG_MARK, APLOG_ERR, s,
+                     "mod_ssl: Cannot spawn ssl_gcache (%s)",
+                     g_szCacheServerPath);
+        ap_clear_pool(pPool);
+        exit(1);
+    }
     return;
 }
 
-static int CacheLauncher(void *cmd, child_info *pInfo)
+static int ssl_CacheLauncher(void *cmd, child_info *pInfo)
 {
     char a1[1024];
 
@@ -1324,12 +1329,14 @@ static int CacheLauncher(void *cmd, child_info *pInfo)
     dup2(STDERR_FILENO, STDOUT_FILENO);
     ap_snprintf(a1, sizeof(a1), "%d", ap_user_id);
     ap_cleanup_for_exec();
-    execl(cmd, "ssl_gcache", a1, g_szCacheServerPort, NULL);
-    perror(cmd);
-    return 1;
+    chdir(ap_coredump_dir);
+    execl((char *)cmd, "ssl_gcache", a1, g_szCacheServerPort, NULL);
+    ap_log_error(APLOG_MARK, APLOG_ERR, g_pServer, 
+                 "failed to spawn ssl_gcache process (%s)", (char *)cmd);
+    return 1 /* faked child_pid */;
 }
 
-static void SendSessionToServer(SSL_SESSION *pSession)
+static void ssl_SendSessionToServer(SSL_SESSION *pSession)
 {
     uchar buf[MAX_SESSION_DER];
     Cache *p;
@@ -1340,14 +1347,14 @@ static void SendSessionToServer(SSL_SESSION *pSession)
 
     pConfig = mySrvConfig(g_pCurrentConnection->server);
 
-    if (LocalCacheFind(pSession->session_id, pSession->session_id_length))
+    if (ssl_gcache_LocalFind(pSession->session_id, pSession->session_id_length))
         return;
 
     tExpiresAt = time(NULL) + pConfig->tSessionCacheTimeout;
 
     t = malloc(pSession->session_id_length);
     memcpy(t, pSession->session_id, pSession->session_id_length);
-    if ((p = LocalCacheAdd(t, pSession->session_id_length, tExpiresAt)) == NULL)
+    if ((p = ssl_gcache_LocalAdd(t, pSession->session_id_length, tExpiresAt)) == NULL)
         return;
 
     t = buf;
@@ -1357,26 +1364,28 @@ static void SendSessionToServer(SSL_SESSION *pSession)
     memcpy(p->aucData, buf, nLength);
     p->nData = nLength;
 
-    GlobalCacheAdd(p->aucKey, p->nKey, p->aucData, p->nData, tExpiresAt);
+    ssl_gcache_GlobalAdd(p->aucKey, p->nKey, p->aucData, p->nData, tExpiresAt);
+    return;
 }
 
-static SSL_SESSION *GetSessionFromServer(uchar *aucSessionID, int nLength)
+static SSL_SESSION *ssl_GetSessionFromServer(uchar *aucSessionID, int nLength)
 {
     SSL_SESSION *pSession;
     Cache *p;
     uchar *t, *t2;
     int nData;
+    time_t tExpiresAt;
 
-    p = LocalCacheFind(aucSessionID, nLength);
+    p = ssl_gcache_LocalFind(aucSessionID, nLength);
     if (!p) {
-        time_t tExpiresAt;
-
-        t = GlobalCacheGet(aucSessionID, nLength, &nData, &tExpiresAt);
-        if (!t)
+        t = ssl_gcache_GlobalGet(aucSessionID, nLength, &nData, &tExpiresAt);
+        if (t == NULL)
             return NULL;
         t2 = malloc(nLength);
         memcpy(t2, aucSessionID, nLength);
-        p = LocalCacheAdd(t2, nLength, tExpiresAt);
+        p = ssl_gcache_LocalAdd(t2, nLength, tExpiresAt);
+        if (p == NULL)
+            return NULL;
         p->aucData = t;
         p->nData = nData;
     }
@@ -1409,6 +1418,9 @@ static void ssl_log_own(SSLConfigRec *pConfig, const char *msg, ...)
 
     va_start(ap, msg);
 
+    if (pConfig->fileLogFile == NULL)
+        return;
+
     t = ap_get_gmtoff(&timz);
     sign = (timz < 0 ? '-' : '+');
     if (timz < 0)
@@ -1432,11 +1444,14 @@ static void ssl_log_ssleay2apache(server_rec *s)
 {
     unsigned long l;
     char buf[MAX_STRING_LEN];
+    SSLConfigRec *pConfig = mySrvConfig(s);
 
     /* Print SSLeay error messages to Apache error log */
     while ((l = __SSLeay ERR_get_error())) {
         __SSLeay ERR_error_string(l, buf);
         ap_log_error(APLOG_MARK, APLOG_ERR|APLOG_NOERRNO, s, "SSLeay: %s", buf);
+        if (pConfig->fileLogFile != NULL)
+            fprintf(pConfig->fileLogFile, "SSLeay: %s\n", buf);
     }
     return;
 }
