@@ -234,10 +234,10 @@ static BOOL         ssl_int_SetCertStuff(conn_rec *);
 static void         ssl_int_SetupVerify(conn_rec *);
 
 /*  Session Cache Support  */
-static void         LaunchCache(server_rec *, pool *);
-static int          CacheLauncher(void *, child_info *);
-static void         SendSessionToServer(SSL_SESSION *);
-static SSL_SESSION *GetSessionFromServer(uchar *, int);
+static void         ssl_LaunchCache(server_rec *, pool *);
+static int          ssl_CacheLauncher(void *, child_info *);
+static void         ssl_SendSessionToServer(SSL_SESSION *);
+static SSL_SESSION *ssl_GetSessionFromServer(uchar *, int);
 
 /*  Logfile Support  */
 static void         ssl_log_own(SSLConfigRec *, const char *, ...);
