@@ -105,6 +105,7 @@
 #include <netinet/in.h>
 #include <sys/un.h>
 #include <unistd.h>
+#include <errno.h>
 #include <signal.h>
 
 /* Apache headers */
@@ -113,73 +114,53 @@
 /* mod_ssl headers */
 #include "ssl_gcache.h"
 
-char *get_time(void);
-void HandleGet(int nFD);
-void HandleClient(int nFD);
-void signal_handler(int sig);
-
 typedef union {
     struct sockaddr_in in;
     struct sockaddr_un un;
 } SockAddr;
 
-char *progname = NULL;
-
-/*
- * In an ideal world, this would come from some Apache supplied library,
- * but well... just try it :-)
- */
-char *get_time(void)
-{
-    time_t t;
-    char *time_string;
-
-    t = time(NULL);
-    time_string = ctime(&t);
-    time_string[strlen(time_string)-1] = '\0';
-    return (time_string);
-}
-
-static void HandleAdd(int nFD)
+static void ssl_gcache_HandleAdd(int nFD)
 {
     uchar *aucKey;
     int nKey;
     Cache *p;
 
-    aucKey = ReadThing(nFD, &nKey);
+    aucKey = ssl_gcache_ReadThing(nFD, &nKey);
     if (aucKey == NULL)
         return;
-    if ((p = LocalCacheFind(aucKey, nKey)) != NULL) {
+    if ((p = ssl_gcache_LocalFind(aucKey, nKey)) != NULL) {
         free(p->aucData);
         free(aucKey);
     }
     else {
-        p = LocalCacheAdd(aucKey, nKey, 0);
+        p = ssl_gcache_LocalAdd(aucKey, nKey, 0);
+        if (p == NULL)
+            return;
     }
-    p->aucData = ReadThing(nFD, &p->nData);
+    p->aucData = ssl_gcache_ReadThing(nFD, &p->nData);
     read(nFD, &p->tExpiresAt, sizeof(p->tExpiresAt));
 }
 
-void HandleGet(int nFD)
+static void ssl_gcache_HandleGet(int nFD)
 {
     uchar *aucKey;
     int nKey;
     Cache *p;
 
-    aucKey = ReadThing(nFD, &nKey);
+    aucKey = ssl_gcache_ReadThing(nFD, &nKey);
     if (aucKey == NULL)
         return;
-    if ((p = LocalCacheFind(aucKey, nKey)) == NULL) { 
-        WriteThing(nFD, NULL, 0);
+    if ((p = ssl_gcache_LocalFind(aucKey, nKey)) == NULL) { 
+        ssl_gcache_WriteThing(nFD, NULL, 0);
     }
     else {
-        WriteThing(nFD, p->aucData, p->nData);
+        ssl_gcache_WriteThing(nFD, p->aucData, p->nData);
         write(nFD, &p->tExpiresAt, sizeof(p->tExpiresAt));
     }
     return;
 }
 
-void HandleClient(int nFD)
+static void ssl_gcache_HandleClient(int nFD)
 {
     static char c;
 
@@ -187,18 +168,21 @@ void HandleClient(int nFD)
         return;
     switch (c) {
         case ADD_TO_CACHE:
-            HandleAdd(nFD);
+            ssl_gcache_HandleAdd(nFD);
             break;
         case GET_FROM_CACHE:
-            HandleGet(nFD);
+            ssl_gcache_HandleGet(nFD);
+            break;
+        default:
+            fprintf(stderr, "[%s] ssl_gcache: invalid cache request\n", ssl_gcache_get_time());
             break;
     }
     return;
 }
 
-void signal_handler(int sig)
+static void signal_handler(int sig)
 {
-    fprintf(stderr, "[%s] %s terminated\n", get_time(), progname);
+    fprintf(stderr, "[%s] ssl_gcache: terminated\n", ssl_gcache_get_time());
     sleep(1);
     exit(0);
 }
@@ -221,11 +205,15 @@ int main(int argc, char **argv)
         exit(1);
     }
 
-    progname = argv[0];
-    fprintf(stderr, "[%s] %s started\n", get_time(), progname);
-    signal(SIGINT, signal_handler);
+    fprintf(stderr, "[%s] ssl_gcache: started\n", ssl_gcache_get_time());
+
+    signal(SIGINT,  signal_handler);
     signal(SIGQUIT, signal_handler);
     signal(SIGTERM, signal_handler);
+#ifdef SIGHUP
+    signal(SIGHUP,  SIG_IGN);
+#endif
+    signal(SIGPIPE, SIG_IGN);
 
     nUserID = atoi(argv[1]);
     szPort  = argv[2];
@@ -236,13 +224,15 @@ int main(int argc, char **argv)
     else
         nSocket = socket(AF_UNIX, SOCK_STREAM, 0);
     if (nSocket < 0) {
-        perror("socket");
+        fprintf(stderr, "[%s] ssl_gcache: socket(): %s\n", 
+                ssl_gcache_get_time(), strerror(errno));
         exit(2);
     }
 
     if (nPort
         && setsockopt(nSocket, SOL_SOCKET, SO_REUSEADDR, (char *) &one, sizeof one) < 0) {
-        perror("setsockopt");
+        fprintf(stderr, "[%s] ssl_gcache: setsockopt(): %s\n", 
+                ssl_gcache_get_time(), strerror(errno));
         exit(7);
     }
 
@@ -262,12 +252,14 @@ int main(int argc, char **argv)
     }
 
     if (bind(nSocket, (struct sockaddr *)&saServer, nSize) < 0) {
-        perror("bind");
+        fprintf(stderr, "[%s] ssl_gcache: bind(): %s\n", 
+                ssl_gcache_get_time(), strerror(errno));
         exit(3);
     }
 
     if (listen(nSocket, 512) < 0) {
-        perror("listen");
+        fprintf(stderr, "[%s] ssl_gcache: listen(): %s\n", 
+                ssl_gcache_get_time(), strerror(errno));
         exit(4);
     }
 
@@ -277,8 +269,8 @@ int main(int argc, char **argv)
     }
 
     if (!geteuid() && setuid(nUserID) == -1) {
-        fprintf(stderr, "[%s] gcache: user id=%d: ", get_time(), nUserID);
-        perror("setuid");
+        fprintf(stderr, "[%s] ssl_gcache: setuid(%d): %s\n", 
+                ssl_gcache_get_time(), nUserID, strerror(errno));
         exit(5);
     }
 
@@ -286,16 +278,16 @@ int main(int argc, char **argv)
         nLen = nSize;
         nFD = accept(nSocket, (struct sockaddr *) &saClient, &nLen);
         if (nFD < 0) {
-            fprintf(stderr, "[%s] gache: accept failed, error=%d\n", get_time(),
-                    errno);
+            fprintf(stderr, "[%s] ssl_gcache: accept(): %s\n", 
+                    ssl_gcache_get_time(), strerror(errno));
             continue;
         }
         if (!nPort || ntohl(saClient.in.sin_addr.s_addr) == 0x7f000001)
-            HandleClient(nFD);
+            ssl_gcache_HandleClient(nFD);
         else
             fprintf(stderr,
-                    "[%s] gcache: unexpected connect from %s, ignored\n",
-                    get_time(), inet_ntoa(saClient.in.sin_addr));
+                    "[%s] ssl_gcache: unexpected connect from %s - ignored\n",
+                    ssl_gcache_get_time(), inet_ntoa(saClient.in.sin_addr));
 
         close(nFD);
     }
