@@ -128,12 +128,13 @@ typedef struct _Cache {
     time_t tExpiresAt;
 } Cache;
 
-void   WriteThing(int, uchar *, int);
-uchar *ReadThing(int, int *);
-Cache *LocalCacheFind(uchar *, int);
-Cache *LocalCacheAdd(uchar *, int, time_t);
-void   InitGlobalCache(const char *);
-void   GlobalCacheAdd(uchar *, int, uchar *, int, time_t);
-uchar *GlobalCacheGet(uchar *, int, int *, time_t *);
+char  *ssl_gcache_get_time(void);
+void   ssl_gcache_WriteThing(int, uchar *, int);
+uchar *ssl_gcache_ReadThing(int, int *);
+void   ssl_gcache_Init(const char *);
+Cache *ssl_gcache_LocalFind(uchar *, int);
+Cache *ssl_gcache_LocalAdd(uchar *, int, time_t);
+void   ssl_gcache_GlobalAdd(uchar *, int, uchar *, int, time_t);
+uchar *ssl_gcache_GlobalGet(uchar *, int, int *, time_t *);
 
 #endif /* SSL_GCACHE_H */
