@@ -105,6 +105,7 @@
 #include <netinet/in.h>
 #include <sys/un.h>
 #include <unistd.h>
+#include <errno.h>
 #include <string.h>
 
 /* mod_ssl headers */
@@ -117,12 +118,13 @@ typedef union {
 
 static const char *szServerPort;
 
-void InitGlobalCache(const char *szPort)
+void ssl_gcache_Init(const char *szPort)
 {
     szServerPort = szPort;
+    return;
 }
 
-static int OpenServer(void)
+static int ssl_gcache_OpenServer(void)
 {
     int nSize;
     int nSocket;
@@ -135,11 +137,12 @@ static int OpenServer(void)
     else
         nSocket = socket(AF_UNIX, SOCK_STREAM, 0);
     if (nSocket < 0) {
-        perror("socket");
-        exit(2);
+        fprintf(stderr, "[%s] ssl_gcache: socket(): %s\n", 
+                ssl_gcache_get_time(), strerror(errno));
+        return (-1);
     }
 
-    memset(&saServer, 0, sizeof saServer);
+    memset(&saServer, 0, sizeof(saServer));
     if (nServerPort) {
         saServer.in.sin_family = AF_INET;
         saServer.in.sin_addr.s_addr = htonl(0x7f000001);
@@ -153,44 +156,51 @@ static int OpenServer(void)
     }
 
     if (connect(nSocket, (struct sockaddr *)&saServer, nSize)) {
-        perror("connect");
-        exit(2);
+        fprintf(stderr, "[%s] ssl_gcache: connect(): %s\n", 
+                ssl_gcache_get_time(), strerror(errno));
+        return (-1);
     }
     return nSocket;
 }
 
-static void WriteCommand(int nFD, enum Command eCommand)
+static void ssl_gcache_WriteCommand(int nFD, enum Command eCommand)
 {
     char c;
 
     c = eCommand;
     write(nFD, &c, 1);
+    return;
 }
 
-void GlobalCacheAdd(uchar *aucKey, int nKey, uchar *aucData,
+void ssl_gcache_GlobalAdd(uchar *aucKey, int nKey, uchar *aucData,
                     int nData, time_t tExpiresAt)
 {
     int nFD;
         
-    nFD = OpenServer();
-    WriteCommand(nFD, ADD_TO_CACHE);
-    WriteThing(nFD, aucKey, nKey);
-    WriteThing(nFD, aucData, nData);
-    write(nFD, &tExpiresAt, sizeof tExpiresAt);
+    if ((nFD = ssl_gcache_OpenServer()) < 0)
+        return;
+    ssl_gcache_WriteCommand(nFD, ADD_TO_CACHE);
+    ssl_gcache_WriteThing(nFD, aucKey, nKey);
+    ssl_gcache_WriteThing(nFD, aucData, nData);
+    write(nFD, &tExpiresAt, sizeof(tExpiresAt));
     close(nFD);
+    return;
 }
 
-uchar *GlobalCacheGet(uchar *aucKey, int nKey, int *pnData, time_t *ptExpiresAt)
+uchar *ssl_gcache_GlobalGet(uchar *aucKey, int nKey, int *pnData, time_t *ptExpiresAt)
 {
     int nFD;
     uchar *ret;
 
-    nFD = OpenServer();
-    WriteCommand(nFD, GET_FROM_CACHE);
-    WriteThing(nFD, aucKey, nKey);
-    ret = ReadThing(nFD, pnData);
+    if ((nFD = ssl_gcache_OpenServer()) < 0) {
+        *pnData = 0;
+        return NULL;
+    }
+    ssl_gcache_WriteCommand(nFD, GET_FROM_CACHE);
+    ssl_gcache_WriteThing(nFD, aucKey, nKey);
+    ret = ssl_gcache_ReadThing(nFD, pnData);
     if (ret)
-        read(nFD, ptExpiresAt, sizeof *ptExpiresAt);
+        read(nFD, ptExpiresAt, sizeof(*ptExpiresAt));
     close(nFD);
     return ret;
 }
