@@ -100,7 +100,9 @@
 /* OS headers */
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <unistd.h>
+#include <errno.h>
 #include <time.h>
 
 /* mod_ssl headers */
@@ -112,16 +114,22 @@ static Cache *pCache;
 static int nCache;
 static int nCacheMax;
 
-void WriteThing(int nFD, uchar *aucThing, int nLength)
+/*
+ * In an ideal world, this would come from some Apache supplied library,
+ * but well... just try it :-)
+ */
+char *ssl_gcache_get_time(void)
 {
-    unsigned short usLength;
+    time_t t;
+    char *time_string;
 
-    usLength = (unsigned short)nLength;
-    write(nFD, &usLength, sizeof(usLength));
-    write(nFD, aucThing, usLength);
+    t = time(NULL);
+    time_string = ctime(&t);
+    time_string[strlen(time_string)-1] = '\0';
+    return (time_string);
 }
 
-static int saferead(int nFD, void *pBuf, int nLength)
+static int ssl_gcache_saferead(int nFD, void *pBuf, int nLength)
 {
     int n;
     char *acBuf = pBuf;
@@ -130,11 +138,13 @@ static int saferead(int nFD, void *pBuf, int nLength)
     for (n = 0; n < nLength; ) {
         r = read(nFD, acBuf+n, nLength-n);
         if (r < 0) {
-            perror("read in saferead");
+            fprintf(stderr, "[%s] ssl_gcache: read(): %s\n", 
+                    ssl_gcache_get_time(), strerror(errno));
             return r;
         }
         if (r == 0) {
-            fprintf(stderr, "EOF in saferead after %d bytes\n", n);
+            fprintf(stderr, "[%s] ssl_gcache: read EOF after %d bytes\n", 
+                    ssl_gcache_get_time(), n);
             return n;
         }
         n += r;
@@ -142,13 +152,23 @@ static int saferead(int nFD, void *pBuf, int nLength)
     return n;
 }
 
-uchar *ReadThing(int nFD, int *pnLength)
+
+void ssl_gcache_WriteThing(int nFD, uchar *aucThing, int nLength)
+{
+    unsigned short usLength;
+
+    usLength = (unsigned short)nLength;
+    write(nFD, &usLength, sizeof(usLength));
+    write(nFD, aucThing, usLength);
+}
+
+uchar *ssl_gcache_ReadThing(int nFD, int *pnLength)
 {
     unsigned short usLength;
     uchar *aucThing;
     int nRead;
 
-    nRead = saferead(nFD, &usLength, sizeof(usLength));
+    nRead = ssl_gcache_saferead(nFD, &usLength, sizeof(usLength));
     if (nRead != sizeof(usLength) || !usLength) {
         *pnLength = 0;
         return NULL;
@@ -157,7 +177,7 @@ uchar *ReadThing(int nFD, int *pnLength)
         *pnLength = 0;
         return NULL;
     }
-    nRead = saferead(nFD, aucThing, usLength);
+    nRead = ssl_gcache_saferead(nFD, aucThing, usLength);
     if (nRead != usLength) {
         *pnLength = 0;
         return NULL;
@@ -166,7 +186,7 @@ uchar *ReadThing(int nFD, int *pnLength)
     return aucThing;
 }
 
-static void ExpireCache(void)
+static void ssl_gcache_ExpireCache(void)
 {
     int n, m;
     time_t tNow = time(NULL);
@@ -185,11 +205,11 @@ static void ExpireCache(void)
     return;
 }
 
-Cache *LocalCacheFind(uchar *aucKey, int nLength)
+Cache *ssl_gcache_LocalFind(uchar *aucKey, int nLength)
 {
     int n;
 
-    ExpireCache();
+    ssl_gcache_ExpireCache();
     if (aucKey == NULL || nLength == 0)
         return NULL;
     for (n = 0; n < nCache; n++)
@@ -199,11 +219,11 @@ Cache *LocalCacheFind(uchar *aucKey, int nLength)
     return NULL;
 }
 
-Cache *LocalCacheAdd(uchar *aucKey, int nKey, time_t tExpiresAt)
+Cache *ssl_gcache_LocalAdd(uchar *aucKey, int nKey, time_t tExpiresAt)
 {
     int n;
 
-    ExpireCache();
+    ssl_gcache_ExpireCache();
     if (aucKey == NULL || nKey == 0)
         return NULL;
     n = nCache++;
